@@ -1,16 +1,19 @@
-# Copyright 2020 Carl Zeiss Microscopy GmbH
-
+# CZModel provides simple-to-use conversion tools to generate a CZANN to be used in ZEISS ZEN Intellesis Portfolio
+# Copyright 2022 Carl Zeiss Microscopy GmbH
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-
-#    http://www.apache.org/licenses/LICENSE-2.0
-
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+#
+# To obtain a commercial version please contact Carl Zeiss Microscopy GmbH.
 """Provides conversion functions to generate a CZANN from exported TensorFlow models."""
 import os
 import sys
@@ -54,7 +57,7 @@ class BaseConverter(Generic[T, S]):
         spec_type: Type[T],
         conversion_fn: Callable[
             [
-                "Model",
+                Model,
                 S,
                 str,
                 Optional[str],
@@ -76,7 +79,7 @@ class BaseConverter(Generic[T, S]):
         self._spec_type: Type[T] = spec_type
         self.conversion_fn: Callable[
             [
-                "Model",
+                Model,
                 S,
                 str,
                 Optional[str],
