@@ -1,19 +1,21 @@
-# Copyright 2021 Carl Zeiss Microscopy GmbH
-
+# CZModel provides simple-to-use conversion tools to generate a CZANN to be used in ZEISS ZEN Intellesis Portfolio
+# Copyright 2022 Carl Zeiss Microscopy GmbH
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-
-#    http://www.apache.org/licenses/LICENSE-2.0
-
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+#
+# To obtain a commercial version please contact Carl Zeiss Microscopy GmbH.
 """Provides transformations to be added as pre- or post-processing layers to a model utilities."""
-from typing import Any  # pylint: disable=unused-import
-from typing import Optional, Sequence, Tuple, Union
+from typing import Optional, Sequence, Tuple, Union, Any
 import collections.abc
 import warnings
 import numpy as np
@@ -24,13 +26,13 @@ import tensorflow as tf
 class TransposeChannels(tf.keras.layers.Layer):
     """A Keras layer that rearranges the channel order of inputs."""
 
-    def __init__(self, order: "Tuple[int, ...]", *args: "Any", **kwargs: "Any") -> None:
+    def __init__(self, order: Tuple[int, ...], *args: Any, **kwargs: Any) -> None:
         """Initializes the layer.
 
         Arguments:
             order: The order in which the channel dimension will be shuffled.
-            args: Additional arguments that will be passed to the TensorFlow Layer constructor.
-            kwargs: Additional keyword arguments that will be passed to the TensorFlow Layer constructor.
+            *args: Additional arguments that will be passed to the TensorFlow Layer constructor.
+            **kwargs: Additional keyword arguments that will be passed to the TensorFlow Layer constructor.
 
         Raises:
             ValueError: If the provided order contains negative values or does not define an order without gaps.
@@ -48,13 +50,13 @@ class TransposeChannels(tf.keras.layers.Layer):
 
     @tf.function
     def call(  # pylint: disable=W0613 # kwargs required by TensorFlow
-        self, inputs: "tf.Tensor", **kwargs: "Any"
-    ) -> "tf.Tensor":
+        self, inputs: tf.Tensor, **kwargs: Any
+    ) -> tf.Tensor:
         """Rearranges the channel order of the inputs.
 
         Args:
             inputs: An input tensor with the channels in the last dimension.
-            kwargs: Additional keyword arguments.
+            **kwargs: Additional keyword arguments.
 
         Returns:
             The inputs with rearranged channel order.
@@ -76,15 +78,15 @@ class PerImageStandardization(tf.keras.layers.Layer):
 
     @tf.function
     def call(  # pylint: disable=W0613 # kwargs required by TensorFlow
-        self, inputs: "tf.Tensor", **kwargs: "Any"
-    ) -> "tf.Tensor":
+        self, inputs: tf.Tensor, **kwargs: Any
+    ) -> tf.Tensor:
         """Shifts and linearly scales each image.
 
          The image will have mean 0 and variance 1. The image is implicitly converted to float representation.
 
         Args:
             inputs: The image(s) to be standardized.
-            kwargs: Additional keyword arguments.
+            **kwargs: Additional keyword arguments.
 
         Returns:
             The standardized image.
@@ -99,7 +101,7 @@ class PerImageStandardization(tf.keras.layers.Layer):
 class Shift(tf.keras.layers.Layer):
     """A Keras layer that shifts the data."""
 
-    def __init__(self, shift: Tuple[float, ...], *args: "Any", **kwargs: "Any") -> None:
+    def __init__(self, shift: Tuple[float, ...], *args: Any, **kwargs: Any) -> None:
         """Creates an instance of the shift layer.
 
         Args:
@@ -114,13 +116,13 @@ class Shift(tf.keras.layers.Layer):
 
     @tf.function
     def call(  # pylint: disable=W0613 # kwargs required by TensorFlow
-        self, inputs: "tf.Tensor", **kwargs: "Any"
-    ) -> "tf.Tensor":
+        self, inputs: tf.Tensor, **kwargs: Any
+    ) -> tf.Tensor:
         """Shifts and image by constant values.
 
         Args:
             inputs: The image(s) to be shifted.
-            kwargs: Additional keyword arguments.
+            **kwargs: Additional keyword arguments.
 
         Returns:
             The shifted image.
@@ -131,7 +133,7 @@ class Shift(tf.keras.layers.Layer):
 class Scale(tf.keras.layers.Layer):
     """A Keras layer that scales the data."""
 
-    def __init__(self, scale: Tuple[float, ...], *args: "Any", **kwargs: "Any") -> None:
+    def __init__(self, scale: Tuple[float, ...], *args: Any, **kwargs: Any) -> None:
         """Creates an instance of the scale layer.
 
         Args:
@@ -146,13 +148,13 @@ class Scale(tf.keras.layers.Layer):
 
     @tf.function
     def call(  # pylint: disable=W0613 # kwargs required by TensorFlow
-        self, inputs: "tf.Tensor", **kwargs: "Any"
-    ) -> "tf.Tensor":
+        self, inputs: tf.Tensor, **kwargs: Any
+    ) -> tf.Tensor:
         """Scales an image by constant values.
 
         Args:
             inputs: The image(s) to be scaled.
-            kwargs: Additional keyword arguments.
+            **kwargs: Additional keyword arguments.
 
         Returns:
             The scaled image.
@@ -165,8 +167,8 @@ class SigmoidToSoftmaxScores(tf.keras.layers.Layer):
 
     @tf.function
     def call(  # pylint: disable=W0613 # kwargs required by TensorFlow
-        self, inputs: "tf.Tensor", **kwargs: "Any"
-    ) -> "tf.Tensor":
+        self, inputs: tf.Tensor, **kwargs: Any
+    ) -> tf.Tensor:
         """Performs the conversion from sigmoidal outputs to softmax scores in the last dimension.
 
         Args:
@@ -182,17 +184,17 @@ class SigmoidToSoftmaxScores(tf.keras.layers.Layer):
         # pylint: disable=no-self-use
         if inputs.shape[-1] != 1:
             raise ValueError(
-                "The shape of the sigmoid activated input must be 1 on the last dimension. "
-                "Received Tensor of shape {}".format(inputs.shape)
+                f"The shape of the sigmoid activated input must be 1 on the last dimension. "
+                f"Received Tensor of shape {inputs.shape}"
             )
         return tf.concat([inputs, tf.constant(1.0) - inputs], -1)
 
 
 def add_preprocessing_layers(
-    model: "tf.keras.Model",
-    layers: Optional[Union["tf.keras.layers.Layer", Sequence["tf.keras.layers.Layer"]]] = None,
-    spatial_dims: Optional[Tuple["int", "int"]] = None,
-) -> "tf.keras.Model":
+    model: tf.keras.Model,
+    layers: Optional[Union[tf.keras.layers.Layer, Sequence[tf.keras.layers.Layer]]] = None,
+    spatial_dims: Optional[Tuple[int, int]] = None,
+) -> tf.keras.Model:
     """Prepends a given pre-processing layer to a given Keras model.
 
     Args:
@@ -232,9 +234,9 @@ def add_preprocessing_layers(
 
 
 def add_postprocessing_layers(
-    model: "tf.keras.Model",
-    layers: Optional[Union["tf.keras.layers.Layer", Sequence["tf.keras.layers.Layer"]]],
-) -> "tf.keras.Model":
+    model: tf.keras.Model,
+    layers: Optional[Union[tf.keras.layers.Layer, Sequence[tf.keras.layers.Layer]]],
+) -> tf.keras.Model:
     """Appends a given post-processing layer to a given Keras model.
 
     Args:
